@@ -28,10 +28,12 @@ class Plugins:
         
         url = base_url.removesuffix("/") + "/v1/plugins"
         
+        headers = {}
+        headers["user-agent"] = f"speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}"
         
         client = self._security_client
         
-        r = client.request("GET", url)
+        r = client.request("GET", url, headers=headers)
         content_type = r.headers.get("Content-Type")
 
         res = operations.GetPluginsResponse(status_code=r.status_code, content_type=content_type)
@@ -56,11 +58,13 @@ class Plugins:
         
         url = utils.generate_url(base_url, "/v1/plugins/{pluginID}", request.path_params)
         
+        headers = {}
         query_params = utils.get_query_params(request.query_params)
+        headers["user-agent"] = f"speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}"
         
         client = self._security_client
         
-        r = client.request("POST", url, params=query_params)
+        r = client.request("POST", url, params=query_params, headers=headers)
         content_type = r.headers.get("Content-Type")
 
         res = operations.RunPluginResponse(status_code=r.status_code, content_type=content_type)
@@ -86,15 +90,16 @@ class Plugins:
         url = base_url.removesuffix("/") + "/v1/plugins"
         
         headers = {}
-        req_content_type, data, json, files = utils.serialize_request_body(request)
+        req_content_type, data, form = utils.serialize_request_body(request)
         if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
             headers["content-type"] = req_content_type
-        if data is None and json is None:
+        if data is None and form is None:
            raise Exception('request body is required')
+        headers["user-agent"] = f"speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}"
         
         client = self._security_client
         
-        r = client.request("PUT", url, data=data, json=json, files=files, headers=headers)
+        r = client.request("PUT", url, data=data, files=form, headers=headers)
         content_type = r.headers.get("Content-Type")
 
         res = operations.UpsertPluginResponse(status_code=r.status_code, content_type=content_type)
